@@ -52,5 +52,7 @@ function check_asm(iverbose,idebug)
   assert('abs(sum(sum(sum(sum(X))))) < 1e-14');
   asserterr('gf_asm(''volumic'',''V(#1)+=1'')');
   
-  
-  
+  H=[.1 .1 0 0; 0 0 0 0; 0 0 0 1]; R=[4 0 1];
+  [HH,RR]=gf_asm('dirichlet nullspace',sparse(H),R);
+  assert('max(max(abs(full(HH)-[0 -1; 0 1; 1 0; 0 0]))) < 1e-15');
+  assert('max(abs(RR-[0 40 0 1]))<1e-15');
\ No newline at end of file
